@@ -23,8 +23,8 @@ import (
 
 	"fortio.org/fortio/fhttp"
 	"fortio.org/fortio/fnet"
-	"fortio.org/fortio/log"
 	"fortio.org/fortio/stats"
+	"fortio.org/log"
 	"golang.org/x/net/context"
 	"google.golang.org/grpc"
 	"google.golang.org/grpc/credentials"
@@ -61,7 +61,7 @@ func (s *pingSrv) Ping(c context.Context, in *PingMessage) (*PingMessage, error)
 // get a dynamic server). Pass the healthServiceName to use for the
 // grpc service name health check (or pass DefaultHealthServiceName)
 // to be marked as SERVING. Pass maxConcurrentStreams > 0 to set that option.
-func PingServer(port, cert, key, healthServiceName string, maxConcurrentStreams uint32) net.Addr {
+func PingServer(port, healthServiceName string, maxConcurrentStreams uint32, tlsOptions *fhttp.TLSOptions) net.Addr {
 	if healthServiceName == "" {
 		healthServiceName = DefaultHealthServiceName
 	}
@@ -74,12 +74,17 @@ func PingServer(port, cert, key, healthServiceName string, maxConcurrentStreams
 		log.Infof("Setting grpc.MaxConcurrentStreams server to %d", maxConcurrentStreams)
 		grpcOptions = append(grpcOptions, grpc.MaxConcurrentStreams(maxConcurrentStreams))
 	}
-	if cert != "" && key != "" {
-		creds, err := credentials.NewServerTLSFromFile(cert, key)
+	if tlsOptions.Cert != "" && tlsOptions.Key != "" {
+		tlsCfg, err := tlsOptions.TLSConfig()
 		if err != nil {
 			log.Fatalf("Invalid TLS credentials: %v", err)
 		}
-		log.Infof("Using server certificate %v and key %v to construct TLS credentials", cert, key)
+		creds := credentials.NewTLS(tlsCfg)
+		mtls := ""
+		if tlsOptions.MTLS {
+			mtls = "mutual "
+		}
+		log.Printf("Using server cert and key from %v and %v to construct %sTLS credentials", tlsOptions.Cert, tlsOptions.Key, mtls)
 		grpcOptions = append(grpcOptions, grpc.Creds(creds))
 	}
 	grpcServer := grpc.NewServer(grpcOptions...)
@@ -99,8 +104,8 @@ func PingServer(port, cert, key, healthServiceName string, maxConcurrentStreams
 
 // PingServerTCP is PingServer() assuming tcp instead of possible unix domain socket port, returns
 // the numeric port.
-func PingServerTCP(port, cert, key, healthServiceName string, maxConcurrentStreams uint32) int {
-	addr := PingServer(port, cert, key, healthServiceName, maxConcurrentStreams)
+func PingServerTCP(port, healthServiceName string, maxConcurrentStreams uint32, tlsOptions *fhttp.TLSOptions) int {
+	addr := PingServer(port, healthServiceName, maxConcurrentStreams, tlsOptions)
 	if addr == nil {
 		return -1
 	}
@@ -114,6 +119,7 @@ func PingServerTCP(port, cert, key, healthServiceName string, maxConcurrentStrea
 func PingClientCall(serverAddr string, n int, payload string, delay time.Duration, tlsOpts *fhttp.TLSOptions, md metadata.MD,
 ) (float64, error) {
 	o := GRPCRunnerOptions{Destination: serverAddr, TLSOptions: *tlsOpts, Metadata: md}
+	o.dialOptions, o.filteredMetadata = extractDialOptionsAndFilter(md)
 	conn, err := Dial(&o) // somehow this never seem to error out, error comes later
 	if err != nil {
 		return -1, err // error already logged
@@ -122,7 +128,7 @@ func PingClientCall(serverAddr string, n int, payload string, delay time.Duratio
 	cli := NewPingServerClient(conn)
 	outCtx := context.Background()
 	if md.Len() != 0 {
-		outCtx = metadata.NewOutgoingContext(outCtx, md)
+		outCtx = metadata.NewOutgoingContext(outCtx, o.filteredMetadata)
 	}
 	// Warm up:
 	_, err = cli.Ping(outCtx, msg)
@@ -176,7 +182,8 @@ type HealthResultMap map[string]int64
 // service.
 func GrpcHealthCheck(serverAddr, svcname string, n int, tlsOpts *fhttp.TLSOptions, md metadata.MD) (*HealthResultMap, error) {
 	log.Infof("GrpcHealthCheck for %s svc '%s', %d iterations", serverAddr, svcname, n)
-	o := GRPCRunnerOptions{Destination: serverAddr, TLSOptions: *tlsOpts}
+	o := GRPCRunnerOptions{Destination: serverAddr, TLSOptions: *tlsOpts, Metadata: md}
+	o.dialOptions, o.filteredMetadata = extractDialOptionsAndFilter(md)
 	conn, err := Dial(&o)
 	if err != nil {
 		return nil, err
@@ -188,7 +195,7 @@ func GrpcHealthCheck(serverAddr, svcname string, n int, tlsOpts *fhttp.TLSOption
 
 	outCtx := context.Background()
 	if md.Len() != 0 {
-		outCtx = metadata.NewOutgoingContext(outCtx, md)
+		outCtx = metadata.NewOutgoingContext(outCtx, o.filteredMetadata)
 	}
 	for i := 1; i <= n; i++ {
 		start := time.Now()
