@@ -23,7 +23,7 @@ import (
 
 	"fortio.org/fortio/fhttp"
 	"fortio.org/fortio/fnet"
-	"fortio.org/fortio/log"
+	"fortio.org/log"
 	"google.golang.org/grpc/credentials"
 	"google.golang.org/grpc/health/grpc_health_v1"
 	"google.golang.org/grpc/metadata"
@@ -40,10 +40,10 @@ func TestPingServer(t *testing.T) {
 	TLSSecureBadCert := &fhttp.TLSOptions{CACert: failCrt, Insecure: true}
 	TLSInsecure := &fhttp.TLSOptions{Insecure: true}
 	TLSInternet := &fhttp.TLSOptions{}
-	iPort := PingServerTCP("0", "", "", "foo", 0)
+	iPort := PingServerTCP("0", "foo", 0, noTLSO)
 	iAddr := fmt.Sprintf("localhost:%d", iPort)
 	t.Logf("insecure grpc ping server running, will connect to %s", iAddr)
-	sPort := PingServerTCP("0", svrCrt, svrKey, "foo", 0)
+	sPort := PingServerTCP("0", "foo", 0, tlsO)
 	sAddr := fmt.Sprintf("localhost:%d", sPort)
 	t.Logf("secure grpc ping server running, will connect to %s", sAddr)
 	delay := 100 * time.Millisecond
@@ -102,14 +102,14 @@ func TestPingServer(t *testing.T) {
 		t.Errorf("Was expecting dial error when using invalid certificate, didn't get one, got %+v", r)
 	}
 	// 2nd server on same port should fail to bind:
-	newPort := PingServerTCP(strconv.Itoa(iPort), "", "", "will fail", 0)
+	newPort := PingServerTCP(strconv.Itoa(iPort), "will fail", 0, noTLSO)
 	if newPort != -1 {
 		t.Errorf("Didn't expect 2nd server on same port to succeed: %d %d", newPort, iPort)
 	}
 }
 
 func TestDefaultHealth(t *testing.T) {
-	iPort := PingServerTCP("0", "", "", "", 0)
+	iPort := PingServerTCP("0", "", 0, noTLSO)
 	iAddr := fmt.Sprintf("localhost:%d", iPort)
 	t.Logf("insecure grpc ping server running, will connect to %s", iAddr)
 	serving := grpc_health_v1.HealthCheckResponse_SERVING.String()
@@ -129,13 +129,11 @@ func TestSettingMetadata(t *testing.T) {
 	server := &mdTestServer{}
 	addr := server.Serve()
 	TLSInsecure := &fhttp.TLSOptions{Insecure: true}
-	if server.error != nil {
-		t.Fatal(server.error)
-	}
 	tests := []struct {
-		name  string
-		key   string
-		value string
+		name      string
+		key       string
+		serverKey string
+		value     string
 	}{
 		{
 			name:  "valid metadata",
@@ -147,34 +145,39 @@ func TestSettingMetadata(t *testing.T) {
 			key:   "ghi",
 			value: "",
 		},
+		{
+			name:      "authority",
+			key:       "host",
+			serverKey: ":authority",
+			value:     "xyz",
+		},
 	}
+
 	for _, test := range tests {
 		server.mdKey = test.key
+		if test.serverKey != "" {
+			server.mdKey = test.serverKey
+		}
 		server.mdValue = test.value
-		server.error = nil
 		_, err := PingClientCall(addr.String(), 2, "", 0, TLSInsecure, metadata.MD{
 			test.key: []string{test.value},
 		})
 		if err != nil {
 			t.Errorf("PingClientCall test case: %s failed , err: %v", test.name, err)
 		}
-		if server.error != nil {
-			t.Errorf("PingClientCall test case: %s failed , err: %v", test.name, server.error)
-		}
 	}
 
 	for _, test := range tests {
 		server.mdKey = test.key
+		if test.serverKey != "" {
+			server.mdKey = test.serverKey
+		}
 		server.mdValue = test.value
-		server.error = nil
 		_, err := GrpcHealthCheck(addr.String(), "", 2, TLSInsecure, metadata.MD{
 			test.key: []string{test.value},
 		})
 		if err != nil {
 			t.Errorf("GrpcHealthCheck test case: %s failed , err: %v", test.name, err)
 		}
-		if server.error != nil {
-			t.Errorf("GrpcHealthCheck test case: %s failed , err: %v", test.name, server.error)
-		}
 	}
 }
