@@ -15,10 +15,9 @@
 package fhttp // import "fortio.org/fortio/fhttp"
 
 // pprof import to get /debug/pprof endpoints on a mux through SetupPPROF.
+
 import (
 	"bytes"
-	"crypto/tls"
-	"flag"
 	"fmt"
 	"io"
 	"net"
@@ -32,11 +31,11 @@ import (
 	"sync/atomic"
 	"time"
 
-	"fortio.org/fortio/dflag"
+	"fortio.org/dflag"
 	"fortio.org/fortio/fnet"
 	"fortio.org/fortio/jrpc"
-	"fortio.org/fortio/log"
 	"fortio.org/fortio/version"
+	"fortio.org/log"
 	"golang.org/x/net/http2"
 	"golang.org/x/net/http2/h2c"
 )
@@ -45,23 +44,22 @@ import (
 
 var (
 	// Start time of the server (used in debug handler for uptime).
-	startTime time.Time
+	startTime = time.Now()
 	// EchoRequests is the number of request received. Only updated in Debug mode.
-	EchoRequests int64
-	// TODO find a way to only include this on binaries and not library mode (#433).
-	defaultEchoServerParams = dflag.DynString(flag.CommandLine, "echo-server-default-params", "",
+	EchoRequests            int64
+	DefaultEchoServerParams = dflag.New("",
 		"Default parameters/querystring to use if there isn't one provided explicitly. E.g \"status=404&delay=3s\"")
-	fetch2CopiesAllHeader = dflag.DynBool(flag.CommandLine, "proxy-all-headers", true,
+	Fetch2CopiesAllHeader = dflag.NewBool(true,
 		"Determines if only tracing or all headers (and cookies) are copied from request on the fetch2 ui/server endpoint")
-	serverIdleTimeout = dflag.DynDuration(flag.CommandLine, "server-idle-timeout", 30*time.Second, "Default IdleTimeout for servers")
+	ServerIdleTimeout = dflag.New(30*time.Second, "Default IdleTimeout for servers")
 )
 
 // EchoHandler is an http server handler echoing back the input.
 func EchoHandler(w http.ResponseWriter, r *http.Request) {
 	if log.LogVerbose() {
-		LogRequest(r, "Echo") // will also print headers
+		log.LogRequest(r, "Echo") // will also print headers
 	}
-	defaultParams := defaultEchoServerParams.Get()
+	defaultParams := DefaultEchoServerParams.Get()
 	hasQuestionMark := strings.Contains(r.RequestURI, "?")
 	if !hasQuestionMark && len(defaultParams) > 0 {
 		newQS := r.RequestURI + "?" + defaultParams
@@ -189,8 +187,8 @@ func HTTPServer(name string, port string) (*http.ServeMux, net.Addr) {
 func HTTPServerWithHandler(name string, port string, hdlr http.Handler) net.Addr {
 	h2s := &http2.Server{}
 	s := &http.Server{
-		ReadHeaderTimeout: serverIdleTimeout.Get(),
-		IdleTimeout:       serverIdleTimeout.Get(),
+		ReadHeaderTimeout: ServerIdleTimeout.Get(),
+		IdleTimeout:       ServerIdleTimeout.Get(),
 		Handler:           h2c.NewHandler(hdlr, h2s),
 	}
 	listener, addr := fnet.Listen(name, port)
@@ -206,19 +204,24 @@ func HTTPServerWithHandler(name string, port string, hdlr http.Handler) net.Addr
 	return addr
 }
 
-func HTTPSServer(name string, port string, certFile string, keyFile string) (*http.ServeMux, net.Addr) {
+func HTTPSServer(name string, port string, to *TLSOptions) (*http.ServeMux, net.Addr) {
 	listener, addr := fnet.Listen(name, port)
 	if listener == nil {
 		return nil, nil // error already logged
 	}
 	m := http.NewServeMux()
+	tlsConfig, err := to.TLSConfig()
+	if err != nil {
+		return nil, nil
+	}
 	s := &http.Server{
-		ReadHeaderTimeout: serverIdleTimeout.Get(),
-		IdleTimeout:       serverIdleTimeout.Get(),
+		ReadHeaderTimeout: ServerIdleTimeout.Get(),
+		IdleTimeout:       ServerIdleTimeout.Get(),
 		Handler:           m,
+		TLSConfig:         tlsConfig,
 	}
 	go func() {
-		err := s.ServeTLS(listener, certFile, keyFile)
+		err := s.ServeTLS(listener, to.Cert, to.Key)
 		if err != nil {
 			log.Fatalf("Unable to TLS serve %s on %s: %v", name, addr.String(), err)
 		}
@@ -238,9 +241,8 @@ func DynamicHTTPServer(closing bool) (*http.ServeMux, *net.TCPAddr) {
 		return mux, addr.(*net.TCPAddr)
 	}
 	// Note: we actually use the fact it's not supported as an error server for tests - need to change that
-	log.Errf("Secure setup not yet supported. Will just close incoming connections for now")
+	log.Warnf("Closing server requested (for error testing)")
 	listener, addr := fnet.Listen("closing server", "0")
-	// err = http.ServeTLS(listener, nil, "", "") // go 1.9
 	go func() {
 		err := closingServer(listener)
 		if err != nil {
@@ -296,8 +298,11 @@ environment:
 */
 
 // DebugHandler returns debug/useful info to http client.
+// Note this can be dangerous and shouldn't be exposed to the internet.
+// A safer version is available as part of fortio's proxy
+// https://github.com/fortio/proxy/blob/main/rp/reverse_proxy.go
 func DebugHandler(w http.ResponseWriter, r *http.Request) {
-	LogRequest(r, "Debug")
+	log.LogRequest(r, "Debug")
 	var buf bytes.Buffer
 	buf.WriteString("Φορτίο version ")
 	buf.WriteString(version.Long())
@@ -308,7 +313,7 @@ func DebugHandler(w http.ResponseWriter, r *http.Request) {
 	buf.WriteString(hostname)
 	buf.WriteString(" - request from ")
 	buf.WriteString(r.RemoteAddr)
-	buf.WriteString(TLSInfo(r))
+	buf.WriteString(log.TLSInfo(r))
 	buf.WriteString("\n\n")
 	buf.WriteString(r.Method)
 	buf.WriteByte(' ')
@@ -393,17 +398,17 @@ func EchoDebugPath(debugPath string) string {
 // The .Port can be retrieved from it when requesting the 0 port as
 // input for dynamic http server.
 func Serve(port, debugPath string) (*http.ServeMux, net.Addr) {
-	return ServeTLS(port, debugPath, "", "")
+	return ServeTLS(port, debugPath, &TLSOptions{})
 }
 
 // ServeTLS starts a debug / echo server on the given port,
 // using TLS if certPath and keyPath aren't not empty.
-func ServeTLS(port, debugPath, certPath, keyPath string) (*http.ServeMux, net.Addr) {
+func ServeTLS(port, debugPath string, to *TLSOptions) (*http.ServeMux, net.Addr) {
 	startTime = time.Now()
 	var mux *http.ServeMux
 	var addr net.Addr
-	if certPath != "" && keyPath != "" {
-		mux, addr = HTTPSServer("https-echo", port, certPath, keyPath)
+	if to.Cert != "" && to.Key != "" {
+		mux, addr = HTTPSServer("https-echo", port, to)
 	} else {
 		mux, addr = HTTPServer("http-echo", port)
 	}
@@ -447,7 +452,7 @@ var proxyClient = CreateProxyClient()
 // new request with all headers copied (allows to test sticky routing)
 // Note this should only be made available to trusted clients.
 func FetcherHandler2(w http.ResponseWriter, r *http.Request) {
-	LogRequest(r, "Fetch proxy2")
+	log.LogRequest(r, "Fetch proxy2")
 	query := r.URL.Query()
 	vals, ok := query["url"]
 	if !ok {
@@ -462,7 +467,7 @@ func FetcherHandler2(w http.ResponseWriter, r *http.Request) {
 	if !strings.HasPrefix(url, "http://") && !strings.HasPrefix(url, "https://") {
 		url = "http://" + url
 	}
-	req := MakeSimpleRequest(url, r, fetch2CopiesAllHeader.Get())
+	req := MakeSimpleRequest(url, r, Fetch2CopiesAllHeader.Get())
 	if req == nil {
 		http.Error(w, "parsing url failed, invalid url", http.StatusBadRequest)
 		return
@@ -492,7 +497,7 @@ func FetcherHandler2(w http.ResponseWriter, r *http.Request) {
 
 // FetcherHandler is the handler for the fetcher/proxy.
 func FetcherHandler(w http.ResponseWriter, r *http.Request) {
-	LogRequest(r, "Fetch (prefix stripped)")
+	log.LogRequest(r, "Fetch (prefix stripped)")
 	hj, ok := w.(http.Hijacker)
 	if !ok {
 		log.Errf("hijacking not supported: %v", r.Proto)
@@ -529,51 +534,20 @@ func FetcherHandler(w http.ResponseWriter, r *http.Request) {
 // RedirectToHTTPSHandler handler sends a redirect to same URL with https.
 func RedirectToHTTPSHandler(w http.ResponseWriter, r *http.Request) {
 	dest := "https://" + r.Host + r.URL.String()
-	LogRequest(r, "Redirecting to "+dest)
+	log.LogRequest(r, "Redirecting to "+dest)
 	http.Redirect(w, r, dest, http.StatusSeeOther)
 }
 
 // RedirectToHTTPS Sets up a redirector to https on the given port.
 // (Do not create a loop, make sure this is addressed from an ingress).
 func RedirectToHTTPS(port string) net.Addr {
-	m, a := HTTPServer("https redirector", port)
-	if m == nil {
-		return nil // error already logged
-	}
-	m.HandleFunc("/", RedirectToHTTPSHandler)
-	return a
-}
-
-// TLSInfo returns " https <cipher suite>" if the request is using TLS, or "" otherwise.
-func TLSInfo(r *http.Request) string {
-	if r.TLS == nil {
-		return ""
-	}
-	return fmt.Sprintf(" https %s", tls.CipherSuiteName(r.TLS.CipherSuite))
-}
-
-// LogRequest logs the incoming request, including headers when loglevel is verbose.
-func LogRequest(r *http.Request, msg string) {
-	if log.Log(log.Info) {
-		tlsInfo := TLSInfo(r)
-		log.Printf("%s: %v %v %v %v (%v) %s %q%s", msg, r.Method, r.URL, r.Proto, r.RemoteAddr,
-			r.Header.Get("X-Forwarded-Proto"), r.Header.Get("X-Forwarded-For"), r.Header.Get("User-Agent"), tlsInfo)
-	}
-	if log.LogVerbose() {
-		// Host is removed from headers map and put separately
-		log.Printf("Header Host: %v", r.Host)
-		for name, headers := range r.Header {
-			for _, h := range headers {
-				log.Printf("Header %v: %v\n", name, h)
-			}
-		}
-	}
+	return HTTPServerWithHandler("https redirector", port, http.HandlerFunc(RedirectToHTTPSHandler))
 }
 
 // LogAndCall wraps an HTTP handler to log the request first.
 func LogAndCall(msg string, hf http.HandlerFunc) http.HandlerFunc {
 	return http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
-		LogRequest(r, msg)
+		log.LogRequest(r, msg)
 		hf(w, r)
 	})
 }
@@ -581,7 +555,7 @@ func LogAndCall(msg string, hf http.HandlerFunc) http.HandlerFunc {
 // LogAndCallNoArg is LogAndCall for functions not needing the response/request args.
 func LogAndCallNoArg(msg string, f func()) http.HandlerFunc {
 	return http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
-		LogRequest(r, msg)
+		log.LogRequest(r, msg)
 		f()
 	})
 }
