@@ -19,7 +19,6 @@ import (
 	"crypto/tls"
 	"crypto/x509"
 	"encoding/base64"
-	"flag"
 	"html/template"
 	"io"
 	"math/rand"
@@ -31,26 +30,27 @@ import (
 	"time"
 	"unicode/utf8"
 
-	"fortio.org/fortio/dflag"
+	"fortio.org/dflag"
 	"fortio.org/fortio/fnet"
 	"fortio.org/fortio/jrpc"
-	"fortio.org/fortio/log"
 	"fortio.org/fortio/stats"
+	"fortio.org/log"
 )
 
 // TLSOptions are common TLS related options between https and grpc.
 type TLSOptions struct {
 	Insecure         bool   // Do not verify certs
+	MTLS             bool   // Use mutual TLS, require client cert
 	CACert           string // `Path` to a custom CA certificate file to be used
 	Cert             string // `Path` to the certificate file to be used
 	Key              string // `Path` to the key file used
 	UnixDomainSocket string // `Path`` of unix domain socket to use instead of host:port
 }
 
-// TLSClientConfig creates a tls.Config based on input TLSOptions.
+// TLSConfig creates a tls.Config based on input TLSOptions.
 // For https, ServerName is set later (once host is determined after URL parsing
-// and depending on hostOverride).
-func (to *TLSOptions) TLSClientConfig() (*tls.Config, error) {
+// and depending on hostOverride). Used for both client and server TLS config.
+func (to *TLSOptions) TLSConfig() (*tls.Config, error) {
 	res := &tls.Config{MinVersion: tls.VersionTLS12}
 	if to.Insecure {
 		log.LogVf("Using insecure https")
@@ -76,6 +76,10 @@ func (to *TLSOptions) TLSClientConfig() (*tls.Config, error) {
 		caCertPool.AppendCertsFromPEM(caCert)
 		res.RootCAs = caCertPool
 	}
+	if to.MTLS {
+		res.ClientAuth = tls.RequireAndVerifyClientCert
+		res.ClientCAs = res.RootCAs
+	}
 	return res, nil
 }
 
@@ -370,7 +374,7 @@ func generateSize(sizeInput string) (size int) {
 
 // MaxDelay is the maximum delay allowed for the echoserver responses.
 // It is a dynamic flag with default value of 1.5s so we can test the default 1s timeout in envoy.
-var MaxDelay = dflag.DynDuration(flag.CommandLine, "max-echo-delay", 1500*time.Millisecond,
+var MaxDelay = dflag.New(1500*time.Millisecond,
 	"Maximum sleep time for delay= echo server parameter. dynamic flag.")
 
 // generateDelay from string, format: delay="100ms" for 100% 100ms delay
